@@ -186,6 +186,11 @@ def _timezone_dst_offsets(api_inputs: ApiInputs, date_from: datetime.date, date_
             return response_status, pandas.DataFrame()
 
         timezone_intervals = json.loads(response.text)
+
+        if not set(['installationTimezoneList','dstTransitions', 'dstIntervals']).issubset(timezone_intervals.columns):
+            logger.error('No Timezone DST Intervals returned for this API call. %s', response.request.url)
+            return response_status, pandas.DataFrame()
+
         site_timezones = pandas.DataFrame.from_dict(timezone_intervals['installationTimezoneList'])
         timezone_offsets = pandas.DataFrame.from_dict(timezone_intervals['dstTransitions'])
         timezone_offsets = timezone_offsets.explode('dstIntervals')
